pub struct FingerResponseStructuredUserEntry {Show 14 fields
pub username: String,
pub full_name: String,
pub home_dir: PathBuf,
pub shell: PathBuf,
pub office: Option<String>,
pub office_phone: Option<String>,
pub home_phone: Option<String>,
pub never_logged_in: bool,
pub sessions: Vec<FingerResponseUserSession>,
pub forward_status: Option<String>,
pub mail_status: Option<MailStatus>,
pub pgp_key: Option<String>,
pub project: Option<String>,
pub plan: Option<String>,
}Fields
username: StringThe unix username of this user, as noted in passwd
full_name: StringThe full name of this user, as noted in passwd
home_dir: PathBufThe path to the home directory of this user, as noted in passwd
shell: PathBufThe path to the shell of this user, as noted in passwd
office: Option<String>Office location, if available
office_phone: Option<String>Office phone number, if available
home_phone: Option<String>Home phone number, if available
never_logged_in: boolWhether the user has never logged in to this host
sessions: Vec<FingerResponseUserSession>A list of user sessions, sourced from utmp entries
forward_status: Option<String>Contents of ~/.forward, if it exists
mail_status: Option<MailStatus>Whether the user has new or unread mail
pgp_key: Option<String>Contents of ~/.pgpkey, if it exists
project: Option<String>Contents of ~/.project, if it exists
plan: Option<String>Contents of ~/.plan, if it exists
Implementations
Sourceimpl FingerResponseStructuredUserEntry
impl FingerResponseStructuredUserEntry
pub fn new( username: String, full_name: String, home_dir: PathBuf, shell: PathBuf, office: Option<String>, office_phone: Option<String>, home_phone: Option<String>, never_logged_in: bool, sessions: Vec<FingerResponseUserSession>, forward_status: Option<String>, mail_status: Option<MailStatus>, pgp_key: Option<String>, project: Option<String>, plan: Option<String>, ) -> Self
Sourcepub fn try_from_raw_finger_response(
response: &RawFingerResponse,
username: String,
) -> Result<Self>
pub fn try_from_raw_finger_response( response: &RawFingerResponse, username: String, ) -> Result<Self>
Try parsing a FingerResponseUserEntry from the text format used by bsd-finger.
pub fn classic_format(&self) -> String