pub struct FingerResponseUserSession {
pub tty: String,
pub login_time: DateTime<Utc>,
pub host: Option<String>,
pub idle_time: Option<TimeDelta>,
pub messages_on: bool,
}Fields
tty: StringThe tty on which this session exists
login_time: DateTime<Utc>When the user logged in and created this session
host: Option<String>The hostname or address of the machine from which the user is logged in, if available
idle_time: Option<TimeDelta>The amount of time since the use last interacted with the tty
messages_on: boolWhether this tty is writable, and thus can receive messages via mesg(1)
Implementations