RwhodConfig

Struct RwhodConfig 

pub struct RwhodConfig {
    pub enable: bool,
    pub ignore_list_path: Option<PathBuf>,
    pub interfaces: Option<HashSet<String>>,
    pub send_interval_seconds: Option<u64>,
    pub max_status_entries: Option<usize>,
    pub realtime_updates: Option<bool>,
}

Fields

enable: bool

Enable or disable the rwhod server functionality.

ignore_list_path: Option<PathBuf>

Path to the ignore list for users that should be hidden from rwhod.

interfaces: Option<HashSet<String>>

Network interfaces to send rwhod packets on (e.g., [“eth0”, “wlan0”]).

If left as None, the server will send on all relevant interfaces it can find.

send_interval_seconds: Option<u64>

Interval between rwhod status packet broadcasts.

If left as None, defaults to 60 seconds.

max_status_entries: Option<usize>

Maximum number of distinct hosts to keep rwhod status records for at the same time. Once at capacity, the least recently updated record is evicted to make room for a newly-seen host.

If left as None, defaults to 4096.

realtime_updates: Option<bool>

Whether to react to Linux audit log activity (e.g. logins/logouts) and push a status update immediately, instead of only on the regular send_interval_seconds interval.

If left as None, defaults to false.

Implementations

Source

impl RwhodConfig

pub fn send_interval(&self) -> Duration

Resolves Self::send_interval_seconds into a concrete interval.

pub fn max_status_entries(&self) -> usize

Resolves Self::max_status_entries into a concrete limit.

pub fn realtime_updates_enabled(&self) -> bool

Resolves Self::realtime_updates into a concrete flag.