struct LoginSessionProxy<'p>(Proxy<'p>);Tuple Fields
0: Proxy<'p>Implementations
Sourceimpl<'p> LoginSessionProxy<'p>
impl<'p> LoginSessionProxy<'p>
Sourcepub async fn new<D, P>(
conn: &Connection,
destination: D,
path: P,
) -> Result<LoginSessionProxy<'p>>
pub async fn new<D, P>( conn: &Connection, destination: D, path: P, ) -> Result<LoginSessionProxy<'p>>
Creates a new proxy with the given service destination and path.
Sourcepub fn builder(conn: &Connection) -> Builder<'p, Self>
pub fn builder(conn: &Connection) -> Builder<'p, Self>
Returns a customizable builder for this proxy.
Sourcepub fn into_inner(self) -> Proxy<'p>
pub fn into_inner(self) -> Proxy<'p>
Consumes self, returning the underlying zbus::Proxy.
Sourcepub fn inner_mut(&mut self) -> &mut Proxy<'p>
pub fn inner_mut(&mut self) -> &mut Proxy<'p>
The mutable reference to the underlying zbus::Proxy.
pub async fn id(&self) -> Result<String>
Sourcepub fn cached_id(
&self,
) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
pub fn cached_id( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
Get the cached value of the Id property, or None if the property is not cached.
Sourcepub async fn receive_id_changed(
&self,
) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>
pub async fn receive_id_changed( &self, ) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>
Create a stream for the Id property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.