audit_change_notifier

Function audit_change_notifier 

pub async fn audit_change_notifier(sender: Sender<()>, socket_fd: OwnedFd)
Listens for audit messages on the systemd-provided netlink socket and sends a notification on the provided channel whenever a user session is opened or closed, indicating that there rwhod status may have changed.