pub fn determine_relevant_interfaces(
allowed_interfaces: Option<&HashSet<String>>,
) -> Result<Vec<RwhodSendTarget>>Expand description
Find all networks network interfaces suitable for rwhod communication.
If allowed_interfaces is Some, only interfaces whose name is contained
in it are considered; otherwise all suitable interfaces are returned.