pub enum VarlinkWalldClientError {
Disabled,
NotAuthorized,
UserNotLoggedIn {
user: String,
},
MessagesDisabled {
user: String,
},
TtyNotFound {
user: String,
tty: String,
},
InvalidRequest {
message: String,
},
TimedOut,
Io {
message: String,
},
}Variants
Disabled
The walld service is not enabled on the server.
NotAuthorized
Caller was not authorized by polkit to perform the request.
UserNotLoggedIn
The target user is not logged in anywhere.
MessagesDisabled
The target user has disabled incoming messages on the relevant tty/ttys.
TtyNotFound
The requested tty does not belong to the target user, or does not exist.
InvalidRequest
The request parameters were invalid (e.g. unknown group).
TimedOut
The request timed out.
Io
Something went wrong while talking to the tty (open/write failure).