pub trait VarlinkRwhodClientProxyChain<'c, S>where
S: Socket,{
// Required methods
fn rwho(self, max_idle_seconds: Option<i64>) -> Result<Chain<'c, S>>;
fn ruptime(self, max_idle_seconds: Option<i64>) -> Result<Chain<'c, S>>;
}Expand description
Extension trait for adding proxy calls to any chain.
This trait provides methods to add proxy calls to a chain of method calls.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".