VarlinkFingerClientProxyChain

Trait VarlinkFingerClientProxyChain 

pub trait VarlinkFingerClientProxyChain<'c, S>
where S: Socket,
{ // Required method fn finger( self, user_queries: Option<Vec<String>>, match_fullnames: bool, request_info: FingerRequestInfo, request_networking: FingerRequestNetworking, disable_user_account_db: bool, raw_remote_output: bool, ) -> Result<Chain<'c, S>>; }
Extension trait for adding proxy calls to any chain.

This trait provides methods to add proxy calls to a chain of method calls.

Required Methods

fn finger( self, user_queries: Option<Vec<String>>, match_fullnames: bool, request_info: FingerRequestInfo, request_networking: FingerRequestNetworking, disable_user_account_db: bool, raw_remote_output: bool, ) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

Implementations on Foreign Types

Source

impl<'c, S> VarlinkFingerClientProxyChain<'c, S> for Chain<'c, S>
where S: Socket,

Source

fn finger( self, user_queries: Option<Vec<String>>, match_fullnames: bool, request_info: FingerRequestInfo, request_networking: FingerRequestNetworking, disable_user_account_db: bool, raw_remote_output: bool, ) -> Result<Chain<'c, S>>

Implementors