VarlinkRwhodClientProxy

Trait VarlinkRwhodClientProxy 

pub trait VarlinkRwhodClientProxy {
    type Socket: Socket;

    // Required methods
    async fn rwho(
        &mut self,
        max_idle_seconds: Option<i64>,
    ) -> Result<Result<VarlinkRwhoResponse, VarlinkRwhodClientError>>;
    async fn ruptime(
        &mut self,
        max_idle_seconds: Option<i64>,
    ) -> Result<Result<VarlinkRuptimeResponse, VarlinkRwhodClientError>>;
    fn chain_rwho<'c>(
        &'c mut self,
        max_idle_seconds: Option<i64>,
    ) -> Result<Chain<'c, Self::Socket>>;
    fn chain_ruptime<'c>(
        &'c mut self,
        max_idle_seconds: Option<i64>,
    ) -> Result<Chain<'c, Self::Socket>>;
}

Required Associated Types

type Socket: Socket

The socket type used for the connection.

Required Methods

async fn rwho( &mut self, max_idle_seconds: Option<i64>, ) -> Result<Result<VarlinkRwhoResponse, VarlinkRwhodClientError>>

max_idle_seconds is the maximum idle time (in seconds) for a user to be included in the response. None means no limit (i.e. the old all: true). The client is expected to always send an explicit value, defaulting to whatever it considers reasonable if the user didn’t ask for a specific limit.

async fn ruptime( &mut self, max_idle_seconds: Option<i64>, ) -> Result<Result<VarlinkRuptimeResponse, VarlinkRwhodClientError>>

See VarlinkRwhodClientProxy::rwho for the meaning of max_idle_seconds.

fn chain_rwho<'c>( &'c mut self, max_idle_seconds: Option<i64>, ) -> Result<Chain<'c, Self::Socket>>

Start a chain with this method call.

fn chain_ruptime<'c>( &'c mut self, max_idle_seconds: Option<i64>, ) -> Result<Chain<'c, Self::Socket>>

Start a chain with this method call.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<S> VarlinkRwhodClientProxy for Connection<S>
where S: Socket,

Source

type Socket = S

Source

async fn rwho( &mut self, max_idle_seconds: Option<i64>, ) -> Result<Result<VarlinkRwhoResponse, VarlinkRwhodClientError>>

Source

async fn ruptime( &mut self, max_idle_seconds: Option<i64>, ) -> Result<Result<VarlinkRuptimeResponse, VarlinkRwhodClientError>>

Source

fn chain_rwho<'c>( &'c mut self, max_idle_seconds: Option<i64>, ) -> Result<Chain<'c, Self::Socket>>

Source

fn chain_ruptime<'c>( &'c mut self, max_idle_seconds: Option<i64>, ) -> Result<Chain<'c, Self::Socket>>

Implementors