VarlinkRwhodClientProxyChain

Trait VarlinkRwhodClientProxyChain 

pub trait VarlinkRwhodClientProxyChain<'c, S>
where S: Socket,
{ // Required methods fn rwho(self, max_idle_seconds: Option<i64>) -> Result<Chain<'c, S>>; fn ruptime(self, max_idle_seconds: Option<i64>) -> Result<Chain<'c, S>>; }
Extension trait for adding proxy calls to any chain.

This trait provides methods to add proxy calls to a chain of method calls.

Required Methods

fn rwho(self, max_idle_seconds: Option<i64>) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

fn ruptime(self, max_idle_seconds: Option<i64>) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'c, S> VarlinkRwhodClientProxyChain<'c, S> for Chain<'c, S>
where S: Socket,

Source

fn rwho(self, max_idle_seconds: Option<i64>) -> Result<Chain<'c, S>>

Source

fn ruptime(self, max_idle_seconds: Option<i64>) -> Result<Chain<'c, S>>

Implementors