VarlinkWalldClientProxy

Trait VarlinkWalldClientProxy 

pub trait VarlinkWalldClientProxy {
    type Socket: Socket;

    // Required methods
    async fn wall(
        &mut self,
        source_tty: Option<String>,
        message: String,
        group: Option<String>,
        nobanner: bool,
        timeout_secs: u32,
    ) -> Result<Result<VarlinkWalldClientResponse, VarlinkWalldClientError>>;
    async fn write(
        &mut self,
        source_tty: Option<String>,
        target_user: String,
        target_tty: Option<String>,
        message: String,
    ) -> Result<Result<VarlinkWalldClientResponse, VarlinkWalldClientError>>;
    fn chain_wall<'c>(
        &'c mut self,
        source_tty: Option<String>,
        message: String,
        group: Option<String>,
        nobanner: bool,
        timeout_secs: u32,
    ) -> Result<Chain<'c, Self::Socket>>;
    fn chain_write<'c>(
        &'c mut self,
        source_tty: Option<String>,
        target_user: String,
        target_tty: Option<String>,
        message: String,
    ) -> Result<Chain<'c, Self::Socket>>;
}

Required Associated Types

type Socket: Socket

The socket type used for the connection.

Required Methods

async fn wall( &mut self, source_tty: Option<String>, message: String, group: Option<String>, nobanner: bool, timeout_secs: u32, ) -> Result<Result<VarlinkWalldClientResponse, VarlinkWalldClientError>>

Broadcast message to the tty of every logged in user, optionally restricted to group.

async fn write( &mut self, source_tty: Option<String>, target_user: String, target_tty: Option<String>, message: String, ) -> Result<Result<VarlinkWalldClientResponse, VarlinkWalldClientError>>

Send message to a the tty of a single user, optionally targeting a specific tty.

fn chain_wall<'c>( &'c mut self, source_tty: Option<String>, message: String, group: Option<String>, nobanner: bool, timeout_secs: u32, ) -> Result<Chain<'c, Self::Socket>>

Start a chain with this method call.

fn chain_write<'c>( &'c mut self, source_tty: Option<String>, target_user: String, target_tty: Option<String>, message: String, ) -> Result<Chain<'c, Self::Socket>>

Start a chain with this method call.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<S> VarlinkWalldClientProxy for Connection<S>
where S: Socket,

Source

type Socket = S

Source

async fn wall( &mut self, source_tty: Option<String>, message: String, group: Option<String>, nobanner: bool, timeout_secs: u32, ) -> Result<Result<VarlinkWalldClientResponse, VarlinkWalldClientError>>

Source

async fn write( &mut self, source_tty: Option<String>, target_user: String, target_tty: Option<String>, message: String, ) -> Result<Result<VarlinkWalldClientResponse, VarlinkWalldClientError>>

Source

fn chain_wall<'c>( &'c mut self, source_tty: Option<String>, message: String, group: Option<String>, nobanner: bool, timeout_secs: u32, ) -> Result<Chain<'c, Self::Socket>>

Source

fn chain_write<'c>( &'c mut self, source_tty: Option<String>, target_user: String, target_tty: Option<String>, message: String, ) -> Result<Chain<'c, Self::Socket>>

Implementors