pub trait VarlinkWalldClientProxyChain<'c, S>where
S: Socket,{
// Required methods
fn wall(
self,
source_tty: Option<String>,
message: String,
group: Option<String>,
nobanner: bool,
timeout_secs: u32,
) -> Result<Chain<'c, S>>;
fn write(
self,
source_tty: Option<String>,
target_user: String,
target_tty: Option<String>,
message: String,
) -> Result<Chain<'c, S>>;
}Expand description
Extension trait for adding proxy calls to any chain.
This trait provides methods to add proxy calls to a chain of method calls.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".