VarlinkWalldClientProxyChain

Trait VarlinkWalldClientProxyChain 

pub trait VarlinkWalldClientProxyChain<'c, S>
where S: Socket,
{ // Required methods fn wall( self, source_tty: Option<String>, message: String, group: Option<String>, nobanner: bool, timeout_secs: u32, ) -> Result<Chain<'c, S>>; fn write( self, source_tty: Option<String>, target_user: String, target_tty: Option<String>, message: String, ) -> Result<Chain<'c, S>>; }
Extension trait for adding proxy calls to any chain.

This trait provides methods to add proxy calls to a chain of method calls.

Required Methods

fn wall( self, source_tty: Option<String>, message: String, group: Option<String>, nobanner: bool, timeout_secs: u32, ) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

fn write( self, source_tty: Option<String>, target_user: String, target_tty: Option<String>, message: String, ) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'c, S> VarlinkWalldClientProxyChain<'c, S> for Chain<'c, S>
where S: Socket,

Source

fn wall( self, source_tty: Option<String>, message: String, group: Option<String>, nobanner: bool, timeout_secs: u32, ) -> Result<Chain<'c, S>>

Source

fn write( self, source_tty: Option<String>, target_user: String, target_tty: Option<String>, message: String, ) -> Result<Chain<'c, S>>

Implementors