pub struct FingerResponseUserSession {
pub tty: String,
pub login_time: DateTime<Utc>,
pub idle_time: TimeDelta,
pub host: String,
pub messages_on: bool,
}Fields
tty: StringThe tty on which this session exists
login_time: DateTime<Utc>When the user logged in and created this session
idle_time: TimeDeltaThe amount of time since the use last interacted with the tty
host: StringThe hostname of the machine where this session is running
messages_on: boolWhether this tty is writable, and thus can receive messages via mesg(1)
Implementations
Sourceimpl FingerResponseUserSession
impl FingerResponseUserSession
pub fn new( tty: String, login_time: DateTime<Utc>, idle_time: TimeDelta, host: String, messages_on: bool, ) -> Self
Sourcefn parse_idle_time(str: &str) -> Result<Duration>
fn parse_idle_time(str: &str) -> Result<Duration>
Parse the idle time from the text string generated by bsd-finger
Sourcepub fn try_from_finger_response_line(line: &str) -> Result<Self>
pub fn try_from_finger_response_line(line: &str) -> Result<Self>
Try parsing a FingerResponseUserSession from the text format used by bsd-finger.