pub trait VarlinkFingerClientProxyChain<'c, S>where
S: Socket,{
// Required method
fn finger(
self,
user_queries: Option<Vec<String>>,
match_fullnames: bool,
request_info: FingerRequestInfo,
request_networking: FingerRequestNetworking,
disable_user_account_db: bool,
raw_remote_output: bool,
) -> Result<Chain<'c, S>>;
}Expand description
Extension trait for adding proxy calls to any chain.
This trait provides methods to add proxy calls to a chain of method calls.